"""Provides all the generic data related to the personal information."""

BLOOD_GROUPS = (
    'O+',
    'A+',
    'B+',
    'AB+',
    'O−',
    'A−',
    'B−',
    'AB−',
)

MUSIC_GENRE = [
    'Pop',
    'Rock',
    'Hard Rock',
    'Rhythm & Blues (R&B)',
    'Country',
    'Rock & Roll',
    'Soul',
    'Country Pop',
    'Pop Rock',
    'Heavy Metal',
    'Progressive Rock',
    'Alternative Rock',
    'Jazz',
    'New Wave',
    'Synthpop',
    'Hip Hop',
    'Folk',
    'New Age',
    'Blues Rock',
    'Ambient',
    'Ambient house',
    'Classic',
    'Neoclassic',
    'Drum and bass',
]

GENDER_SYMBOLS = (
    '♂',
    '♀',
    '⚲',
)

SEXUALITY_SYMBOLS = (
    '⚤',
    '⚢',
    '⚣',
    '⚥',
    '⚧',
    '⚪',
)

ENGLISH_LEVEL = [
    'Beginner',
    'Elementary',
    'Pre - Intermediate',
    'Intermediate',
    'Upper Intermediate',
    'Advanced',
    'Proficiency',
]

USERNAMES = [
    'aardvark',
    'ababa',
    'aback',
    'abaft',
    'abalone',
    'abandoned',
    'abashed',
    'abatis',
    'abdel',
    'abdominal',
    'abele',
    'aberrant',
    'abhorrent',
    'abidal',
    'abiding',
    'abiezer',
    'abilities',
    'abiogenesis',
    'abject',
    'ablaze',
    'able',
    'ablution',
    'abnegative',
    'abnormal',
    'aboard',
    'abody',
    'abolished',
    'abominable',
    'aboriginal',
    'aborter',
    'aborticide',
    'abortive',
    'abounding',
    'abrar',
    'abrasax',
    'abrasive',
    'abridged',
    'abroad',
    'abrupt',
    'abrus',
    'abscess',
    'absconsa',
    'absent',
    'absit',
    'absolute',
    'absorbed',
    'absorbing',
    'abstain',
    'abstinent',
    'abstracted',
    'absurd',
    'abucco',
    'abundant',
    'abundantia',
    'abusers',
    'abusive',
    'abyssinian',
    'acana',
    'acanthurus',
    'acceptable',
    'accessible',
    'accidental',
    'accidia',
    'acclimatise',
    'accurate',
    'aceology',
    'acephalous',
    'acers',
    'achaean',
    'achamma',
    'achates',
    'achira',
    'achmetha',
    'achromic',
    'acid',
    'acidic',
    'aciduria',
    'acinar',
    'ackey',
    'acoustic',
    'acree',
    'acrid',
    'acrite',
    'acrook',
    'acryl',
    'actinon',
    'actually',
    'acuate',
    'acubens',
    'acute',
    'ad',
    'adamant',
    'adamczyk',
    'adansonia',
    'adapa',
    'adaptable',
    'adaptive',
    'adcox',
    'addendum',
    'adders',
    'addicted',
    'addiction',
    'addressee',
    'adebayo',
    'adena',
    'adenitis',
    'adermia',
    'adhesive',
    'adiana',
    'adine',
    'adirondack',
    'adjoining',
    'adjuster',
    'adman',
    'administrate',
    'admissible',
    'admissions',
    'admonisher',
    'adolph',
    'adolphe',
    'adorable',
    'adoree',
    'adorer',
    'adown',
    'adriaan',
    'adriena',
    'adriene',
    'adventure',
    'adventurer',
    'adventuring',
    'adventurous',
    'adverted',
    'advertised',
    'advocate',
    'aeonian',
    'aerobatic',
    'aesthetic',
    'affenpinscher',
    'affiliate',
    'affluent',
    'afloat',
    'afraid',
    'afret',
    'african',
    'afterfuture',
    'afterglow',
    'afterimage',
    'afterlife',
    'afternight',
    'against',
    'agalloch',
    'agamic',
    'agathodaemon',
    'agaty',
    'agdistis',
    'agent',
    'aggies',
    'aggregat',
    'aggressive',
    'agitprop',
    'agnail',
    'agnar',
    'agnatha',
    'agnomen',
    'agnosia',
    'agonal',
    'agonizing',
    'agosto',
    'agreeable',
    'ahead',
    'aiding',
    'aiglet',
    'ailing',
    'aindrea',
    'airflow',
    'airish',
    'airlock',
    'airplay',
    'airtight',
    'aisling',
    'aissaoua',
    'aitch',
    'aiwan',
    'ajar',
    'akbash',
    'akinesia',
    'akita',
    'akkadian',
    'alair',
    'alaite',
    'alanine',
    'alans',
    'alanson',
    'alaric',
    'albata',
    'albatross',
    'albian',
    'alcalde',
    'alcheringa',
    'alcindor',
    'alcoa',
    'alcoholic',
    'alcove',
    'alcyone',
    'aldols',
    'aldus',
    'alegre',
    'alene',
    'alert',
    'alessand',
    'alexandrite',
    'alexas',
    'alexis',
    'alfred',
    'algal',
    'algedi',
    'alger',
    'algerine',
    'algonquin',
    'algorithms',
    'alidia',
    'alien',
    'aliens',
    'aligner',
    'alike',
    'alist',
    'alister',
    'alive',
    'aliyah',
    'alkalurops',
    'alkyds',
    'allan',
    'allard',
    'allay',
    'alleged',
    'allegiances',
    'allegri',
    'alleluia',
    'allen',
    'allergy',
    'alleyway',
    'allgood',
    'allida',
    'alligator',
    'alligators',
    'alliya',
    'allowance',
    'allstate',
    'allthing',
    'alluring',
    'alluvium',
    'almadia',
    'aloed',
    'alogism',
    'aloof',
    'alpaca',
    'alsaleh',
    'alshain',
    'alten',
    'alterant',
    'alterman',
    'altin',
    'altiplano',
    'altitudes',
    'altruistic',
    'aluminosis',
    'alumnal',
    'aluta',
    'alvarez',
    'alvaro',
    'alveolate',
    'alvera',
    'alvine',
    'alway',
    'alyda',
    'alyre',
    'amalgamation',
    'amalie',
    'amarelle',
    'amaryllis',
    'amazing',
    'amazons',
    'ambarella',
    'amber',
    'amberoid',
    'amberous',
    'ambiguous',
    'ambition',
    'ambitions',
    'ambitious',
    'ambivalent',
    'ambivert',
    'ambsace',
    'ambush',
    'ameed',
    'amelina',
    'ameliorators',
    'amgad',
    'amick',
    'amines',
    'ammar',
    'ammeter',
    'amnesia',
    'amontillado',
    'amorim',
    'amorist',
    'amorphia',
    'amour',
    'amperage',
    'amphibia',
    'amphibological',
    'amphigory',
    'amril',
    'amstutz',
    'amuck',
    'amused',
    'amusing',
    'amylan',
    'anabasis',
    'anabel',
    'anaconda',
    'anaesthetic',
    'analogue',
    'analyst',
    'analytic',
    'anamorphose',
    'ananda',
    'anaryan',
    'anasa',
    'anasazi',
    'anastasia',
    'anastasis',
    'anatolic',
    'ancestry',
    'anchors',
    'ancient',
    'ancon',
    'andalusite',
    'ander',
    'andira',
    'andrease',
    'anemone',
    'anemony',
    'anent',
    'anesthetize',
    'angara',
    'angelate',
    'angeleyes',
    'angelfish',
    'angelika',
    'angelo',
    'anglesmith',
    'angostura',
    'angry',
    'anhedonia',
    'animated',
    'animations',
    'anime',
    'anisotropic',
    'anita',
    'ann-marie',
    'annale',
    'annalisa',
    'annamaria',
    'annelid',
    'annemari',
    'annie',
    'annihilates',
    'annoyed',
    'annoyer',
    'annoying',
    'annum',
    'anoop',
    'anoraks',
    'another',
    'anstett',
    'answers',
    'ant',
    'antdom',
    'anteal',
    'anteater',
    'antebellum',
    'antelope',
    'anterograde',
    'anthema',
    'anthems',
    'anthonin',
    'anthonis',
    'anthrol',
    'anthropos',
    'anthuriums',
    'antibiotic',
    'antical',
    'antically',
    'anticyclone',
    'antifowl',
    'antinome',
    'antinormal',
    'antipart',
    'antipodes',
    'antiprime',
    'antisun',
    'antivenom',
    'antivirus',
    'antonin',
    'antonym',
    'antre',
    'antsy',
    'antuan',
    'anukit',
    'anvil',
    'anxious',
    'anything',
    'apaches',
    'apama',
    'apartness',
    'apathetic',
    'apatosaurus',
    'ape',
    'aperies',
    'aphelandra',
    'aphotic',
    'apina',
    'aplomb',
    'aplysia',
    'apoda',
    'apogon',
    'apolline',
    'apologies',
    'aporia',
    'apostrophe',
    'apparition',
    'appetence',
    'appetite',
    'appleblossom',
    'applejack',
    'apples',
    'appleton',
    'application',
    'appointment',
    'appraisal',
    'approachable',
    'april',
    'apron',
    'apropos',
    'aptitude',
    'apurba',
    'aquatic',
    'aqueduct',
    'arachnida',
    'arachnoid',
    'araks',
    'arana',
    'araneid',
    'arbacia',
    'arbel',
    'arcane',
    'archeus',
    'archfiend',
    'archimedes',
    'architectural',
    'architeuthis',
    'arcturia',
    'arcus',
    'ardea',
    'ardelia',
    'ardith',
    'ardys',
    'areito',
    'areopagite',
    'arethusa',
    'argento',
    'arghan',
    'argiope',
    'argonaut',
    'argument',
    'argus',
    'arias',
    'arienzo',
    'arisen',
    'arleng',
    'arles',
    'arley',
    'arlin',
    'arlyn',
    'armadillo',
    'armado',
    'armando',
    'armenoid',
    'arming',
    'armour',
    'armourer',
    'arney',
    'arnis',
    'arnone',
    'arock',
    'aromatic',
    'arora',
    'arpen',
    'arpita',
    'arracacha',
    'arranger',
    'arras',
    'arrays',
    'arrhythmia',
    'arriba',
    'arrogant',
    'arrowy',
    'arsenium',
    'arses',
    'artaba',
    'artemis',
    'arterial',
    'arteries',
    'artery',
    'arthritis',
    'article',
    'articulate',
    'artiller',
    'artiste',
    'artur',
    'arundo',
    'arvin',
    'arzun',
    'asbest',
    'asbestosis',
    'ascanius',
    'ascension',
    'ashamed',
    'ashcake',
    'ashlar',
    'ashleigh',
    'ashlie',
    'ashlin',
    'ashore',
    'ashpan',
    'ashton',
    'asians',
    'asleep',
    'asmear',
    'asoka',
    'asouth',
    'aspersion',
    'aspic',
    'aspidium',
    'aspire',
    'aspiring',
    'ass',
    'assailants',
    'assault',
    'assimilate',
    'assistant',
    'assorted',
    'assuming',
    'asters',
    'astomia',
    'astonisher',
    'astonishing',
    'astor',
    'astoria',
    'astral',
    'astrolabe',
    'astronautic',
    'astrophil',
    'aswan',
    'atavistic',
    'atavus',
    'ateles',
    'athelia',
    'athene',
    'athenor',
    'athletics',
    'atique',
    'atlanta',
    'atlantis',
    'atlas',
    'atman',
    'atmospheric',
    'atoning',
    'atopy',
    'atpco',
    'attractive',
    'attrition',
    'attune',
    'atune',
    'atwood',
    'auberge',
    'aubert',
    'aucan',
    'audette',
    'auditoria',
    'audrie',
    'augeri',
    'augurs',
    'aural',
    'aurevoir',
    'auric',
    'auricularia',
    'aurite',
    'auroras',
    'aurore',
    'auspicious',
    'australi',
    'autocall',
    'autogiro',
    'automatic',
    'available',
    'avalanche',
    'avantgarde',
    'avenger',
    'avenue',
    'average',
    'averardo',
    'avernal',
    'avestan',
    'avgas',
    'aviation',
    'avigdor',
    'avocet',
    'avouch',
    'avuncular',
    'awake',
    'awaken',
    'award',
    'aware',
    'awatch',
    'awave',
    'awesome',
    'awest',
    'awful',
    'awide',
    'awoken',
    'axenic',
    'axiomatic',
    'axled',
    'axolotl',
    'aymara',
    'ayoup',
    'ayukawa',
    'aywie',
    'azhar',
    'azido',
    'azine',
    'azoic',
    'aztecs',
    'azuma',
    'baalath',
    'babak',
    'babbage',
    'baboon',
    'baboonery',
    'babuina',
    'babyface',
    'baccalaureate',
    'bachelor',
    'backcross',
    'backdoor',
    'backers',
    'backgammon',
    'backpacker',
    'backspace',
    'bactrian',
    'badge',
    'badger',
    'badly',
    'badminton',
    'bagdad',
    'bagels',
    'bagging',
    'baggy',
    'baghdadi',
    'bagpipes',
    'bahama',
    'bahamian',
    'baited',
    'bajau',
    'bajury',
    'bakers',
    'baklavas',
    'baktun',
    'balaban',
    'balas',
    'balatron',
    'balboa',
    'balcom',
    'balcony',
    'baldest',
    'baldric',
    'balinese',
    'ballate',
    'ballistae',
    'ballroom',
    'ballsy',
    'balmoral',
    'balmy',
    'balser',
    'balthasar',
    'balunda',
    'bambie',
    'banaba',
    'banat',
    'banda',
    'bande',
    'bandicoot',
    'bandits',
    'bandmaster',
    'banes',
    'banish',
    'banky',
    'bannet',
    'banshie',
    'bantay',
    'banya',
    'baptist',
    'barb',
    'barbara',
    'barbi',
    'barclay',
    'bardolph',
    'bardsley',
    'bares',
    'bargeman',
    'barit',
    'barite',
    'barkery',
    'barkier',
    'barmecide',
    'barnacle',
    'barnstormer',
    'barong',
    'barracuda',
    'barrels',
    'barriere',
    'barse',
    'bartizan',
    'basco',
    'basenji',
    'bashed',
    'basile',
    'basin',
    'basis',
    'basker',
    'baskin',
    'basset',
    'bastille',
    'bastion',
    'bastioned',
    'bat',
    'batara',
    'batch',
    'bateau',
    'bateman',
    'bathe',
    'bathed',
    'batiks',
    'batis',
    'baton',
    'batster',
    'batten',
    'battlegrounds',
    'battlers',
    'battles',
    'battling',
    'batule',
    'batwa',
    'bauch',
    'bayard',
    'bayesian',
    'bazooka',
    'beachman',
    'beachwear',
    'beagle',
    'bealle',
    'bear',
    'beasts',
    'beate',
    'beatitude',
    'beatitudes',
    'beaucoup',
    'beaulieu',
    'beaux',
    'beaver',
    'beaverish',
    'becca',
    'beccafico',
    'bechern',
    'becke',
    'beckoning',
    'become',
    'bedding',
    'bedlamite',
    'bedroom',
    'bedrooms',
    'bedtime',
    'bee',
    'beebe',
    'beechy',
    'beefsteak',
    'beelol',
    'beethovenian',
    'beetle',
    'befouled',
    'begley',
    'behalf',
    'behaviour',
    'behead',
    'beland',
    'belanda',
    'belar',
    'belay',
    'belee',
    'belich',
    'belie',
    'believe',
    'believer',
    'belight',
    'belion',
    'belissa',
    'bellboy',
    'bellhop',
    'bellmaker',
    'bellman',
    'bellwood',
    'bemar',
    'bemis',
    'bemole',
    'bemoon',
    'benares',
    'bench',
    'bender',
    'benight',
    'benjamite',
    'benjie',
    'benni',
    'benthic',
    'benthos',
    'benton',
    'benward',
    'benzein',
    'benzie',
    'beograd',
    'beppie',
    'berberine',
    'berenices',
    'beresfor',
    'berkelium',
    'berkowitz',
    'berlitz',
    'bernadette',
    'bernadin',
    'bernelle',
    'bernice',
    'berri',
    'berthe',
    'beshir',
    'beswick',
    'betaking',
    'bethel',
    'bethlehem',
    'beverlee',
    'beverly',
    'bevin',
    'bevvy',
    'bewitch',
    'bewitching',
    'beylic',
    'bezzo',
    'bhutia',
    'biabo',
    'bianka',
    'bibliomane',
    'bickford',
    'biddie',
    'bider',
    'biedermeier',
    'bifront',
    'biggers',
    'bigha',
    'bigman',
    'bigots',
    'bigwig',
    'bihai',
    'bijan',
    'bijou',
    'biker',
    'bilayer',
    'bilbo',
    'bilio',
    'billable',
    'billiards',
    'billows',
    'billowy',
    'binda',
    'binette',
    'binghi',
    'binits',
    'binman',
    'binturong',
    'biochemical',
    'biogen',
    'biologists',
    'biomagnetic',
    'biomechanics',
    'biosynthesis',
    'biotech',
    'biotechnological',
    'biplab',
    'bird',
    'birdmen',
    'birdseed',
    'birendra',
    'birken',
    'birman',
    'birretta',
    'birthing',
    'birthmark',
    'bison',
    'biteme',
    'bitter',
    'bitterness',
    'bitton',
    'bitumen',
    'biune',
    'bizen',
    'bizonia',
    'blabber',
    'blackbelly',
    'blackberry',
    'blackbirds',
    'blackest',
    'blackfeet',
    'blackings',
    'blackleg',
    'blackman',
    'blackroot',
    'blackseed',
    'blacktongue',
    'blacky',
    'blais',
    'blame',
    'blanca',
    'blanch',
    'blasphemy',
    'blasted',
    'blaze',
    'blazed',
    'blazers',
    'blazon',
    'bleach',
    'bleaching',
    'bleeker',
    'blending',
    'blent',
    'blindeyes',
    'blinkered',
    'blissfully',
    'blisters',
    'blizz',
    'bloch',
    'blockader',
    'bloodhound',
    'bloodless',
    'bloodletting',
    'bloodshedder',
    'bloodsports',
    'bloodstains',
    'blotto',
    'blowing',
    'blows',
    'blowy',
    'blubber',
    'blueberries',
    'bluebill',
    'bluecollar',
    'bluefish',
    'bluely',
    'bluestocking',
    'bluestones',
    'boar',
    'boarding',
    'boards',
    'boars',
    'boaster',
    'boats',
    'bobadil',
    'bobbee',
    'bobber',
    'bobbery',
    'bobby',
    'bobbye',
    'bobcat',
    'bobotie',
    'bobwhite',
    'bocoy',
    'boden',
    'bodhi',
    'bodier',
    'bogard',
    'bogert',
    'bohdan',
    'boiko',
    'boilerman',
    'boing',
    'boisset',
    'bolas',
    'boldface',
    'bolete',
    'bolio',
    'bolshevik',
    'bombay',
    'bombsight',
    'bombyx',
    'bommer',
    'bonanzas',
    'bondon',
    'bonehead',
    'boneless',
    'bongo',
    'bongos',
    'bonita',
    'bonobo',
    'boobies',
    'booby',
    'boodie',
    'boohoo',
    'booking',
    'bookmaker',
    'bookworm',
    'boons',
    'boose',
    'boosters',
    'boother',
    'bopeep',
    'borak',
    'boran',
    'borane',
    'borderless',
    'boreades',
    'borgh',
    'bornagain',
    'borneo',
    'boroughs',
    'borrelli',
    'borsht',
    'boser',
    'bosom',
    'bosomy',
    'bossa',
    'bosset',
    'bossman',
    'bottlefeed',
    'bottleman',
    'bouche',
    'boudreau',
    'bouncy',
    'bounder',
    'bourcier',
    'bourgeois',
    'bourguig',
    'bourlet',
    'bouse',
    'boutade',
    'bouto',
    'bouzouki',
    'bovid',
    'bowers',
    'bowwow',
    'bowyer',
    'boyar',
    'boyscout',
    'brach',
    'brachial',
    'brack',
    'brackets',
    'braddock',
    'bradley',
    'braggers',
    'brahms',
    'brainwasher',
    'brainwork',
    'bramble',
    'brambles',
    'branch',
    'brancher',
    'brandice',
    'brandie',
    'brann',
    'brassard',
    'braunschweiger',
    'breaded',
    'breaker',
    'breakless',
    'breakthrough',
    'breakup',
    'breakwater',
    'breaster',
    'breaststroker',
    'breathless',
    'breeds',
    'breena',
    'breezing',
    'brekel',
    'brennand',
    'breton',
    'brevier',
    'briar',
    'bribe',
    'bridal',
    'bridgeman',
    'bridges',
    'briel',
    'brierley',
    'brigandine',
    'brightly',
    'brimborion',
    'brimful',
    'brims',
    'briolette',
    'british',
    'britt',
    'broadway',
    'brocade',
    'broccoli',
    'broch',
    'brockie',
    'brockman',
    'broddy',
    'brody',
    'brogan',
    'brogues',
    'broking',
    'bromes',
    'bronco',
    'bronk',
    'bronny',
    'bronze',
    'broody',
    'brooklyn',
    'broom',
    'broomer',
    'brose',
    'brownlee',
    'browsers',
    'bruise',
    'brushwood',
    'brushy',
    'brusque',
    'brutter',
    'brydges',
    'brynn',
    'bryophyte',
    'bubak',
    'bubales',
    'buccan',
    'buccina',
    'bucketman',
    'buckeye',
    'buckhorn',
    'buckling',
    'buckman',
    'buddie',
    'budding',
    'buder',
    'budgerigar',
    'buffalo',
    'bufonidae',
    'bugbear',
    'buggyman',
    'bugler',
    'built',
    'bulanda',
    'bulbous',
    'bulgaria',
    'bulimia',
    'bulldog',
    'bullen',
    'bullfrog',
    'bullhorn',
    'bullocks',
    'bumfs',
    'bumpier',
    'bumpy',
    'bunchberry',
    'bunni',
    'burek',
    'burel',
    'burger',
    'burgesses',
    'burgle',
    'burial',
    'burian',
    'burin',
    'burker',
    'burkey',
    'burley',
    'burlie',
    'burmese',
    'burps',
    'burrower',
    'burrus',
    'burry',
    'busby',
    'busch',
    'business',
    'businesswoman',
    'busybody',
    'butcheress',
    'butta',
    'buttered',
    'butterfish',
    'butterfly',
    'butting',
    'buxom',
    'buyable',
    'bygones',
    'byran',
    'byroad',
    'byron',
    'bystreet',
    'caatinga',
    'cabala',
    'cabalist',
    'caballer',
    'caballero',
    'caban',
    'cabasset',
    'cabinda',
    'cablet',
    'caboodle',
    'cabral',
    'cabrio',
    'cacara',
    'cachet',
    'cadaveric',
    'caddle',
    'cadmium',
    'caelum',
    'caffeina',
    'cagatay',
    'caggy',
    'caiman',
    'cajaput',
    'caking',
    'calabrese',
    'calamine',
    'calamite',
    'calcar',
    'calcine',
    'calculous',
    'calcutta',
    'calefacient',
    'calinda',
    'calista',
    'callery',
    'calumny',
    'calvary',
    'camacho',
    'camber',
    'cambeva',
    'cambre',
    'cambrian',
    'cambridge',
    'camden',
    'camel',
    'camelus',
    'cameo',
    'camion',
    'campbell',
    'camper',
    'campo',
    'camused',
    'canadian',
    'canamo',
    'canberra',
    'candida',
    'cangle',
    'canille',
    'cannibal',
    'cannibals',
    'cannikin',
    'canopus',
    'canossa',
    'cantabile',
    'cantalas',
    'cantaloupes',
    'cantharis',
    'canto',
    'cantoral',
    'canuck',
    'canyon',
    'capabler',
    'capelet',
    'capelin',
    'capistrano',
    'capitalism',
    'capitation',
    'caplin',
    'capozzi',
    'caprice',
    'capricornus',
    'capriole',
    'capturer',
    'capuche',
    'capybara',
    'caracal',
    'carambole',
    'carapo',
    'carapus',
    'carayan',
    'carbonite',
    'carburant',
    'carcass',
    'cardamom',
    'cardia',
    'cardiff',
    'carding',
    'career',
    'caregiver',
    'carella',
    'carful',
    'caribou',
    'caridean',
    'carinal',
    'carine',
    'carita',
    'carlean',
    'carlene',
    'carless',
    'carlet',
    'carlett',
    'carlock',
    'carlyle',
    'carmelite',
    'carmencita',
    'carmina',
    'carnations',
    'carnell',
    'carnivore',
    'caroli',
    'carolus',
    'caron',
    'carotid',
    'carpetbag',
    'carpool',
    'carrefour',
    'carrizo',
    'carted',
    'cartesian',
    'carving',
    'casas',
    'cascarilla',
    'casco',
    'caseloads',
    'casey',
    'cashana',
    'cashbox',
    'caslon',
    'cassady',
    'cassandra',
    'cassat',
    'cassolette',
    'cassondra',
    'cassowary',
    'castaways',
    'castell',
    'castilian',
    'castiron',
    'castles',
    'castling',
    'casualist',
    'cat',
    'catacombs',
    'catamenia',
    'catbird',
    'catchpole',
    'caterina',
    'caterpillar',
    'caterpillars',
    'catfight',
    'catfish',
    'catgut',
    'cathedrals',
    'catherina',
    'cathole',
    'catie',
    'cation',
    'cattle',
    'cauchy',
    'cauliflower',
    'causes',
    'cautions',
    'cautivo',
    'cavalero',
    'cavatina',
    'cavish',
    'caxton',
    'cayapa',
    'cayuga',
    'ceara',
    'cebil',
    'cebus',
    'cecon',
    'cedric',
    'ceibo',
    'celadon',
    'celarent',
    'celature',
    'celebrations',
    'celebrity',
    'celesta',
    'cellmate',
    'celloid',
    'cellule',
    'celsius',
    'celtish',
    'cembalo',
    'cementation',
    'cenozoic',
    'cense',
    'censored',
    'centenary',
    'centered',
    'centipede',
    'centrefolds',
    'centric',
    'centrist',
    'centuple',
    'cephalotripsy',
    'ceramics',
    'ceratium',
    'cercocebus',
    'ceremonies',
    'ceriel',
    'cerite',
    'cerulean',
    'ceruleum',
    'ceruse',
    'cessna',
    'chafe',
    'chaja',
    'chaka',
    'chakras',
    'chalon',
    'chalot',
    'chalton',
    'chalumeau',
    'chamade',
    'chameleon',
    'chameleons',
    'chamois',
    'champ',
    'champing',
    'chancery',
    'chances',
    'chandan',
    'chander',
    'chandra',
    'chanson',
    'chanteuse',
    'chaotic',
    'chape',
    'chaperno',
    'chaperone',
    'chapfallen',
    'chaplin',
    'chappy',
    'charging',
    'charil',
    'charlene',
    'charline',
    'charlotte',
    'charmian',
    'charmless',
    'charta',
    'chasing',
    'chatelaine',
    'chaudhry',
    'chaudry',
    'chauffeur',
    'chaute',
    'chavender',
    'chaya',
    'cheapest',
    'chechen',
    'cheeking',
    'cheering',
    'cheetah',
    'cheetham',
    'chegre',
    'chela',
    'chelone',
    'chemistry',
    'chemoreceptor',
    'chenault',
    'cheng',
    'chengwei',
    'cheques',
    'cherimoya',
    'cherish',
    'cherished',
    'cherly',
    'cherlyn',
    'cherokee',
    'cherries',
    'cheryl',
    'chetan',
    'chewer',
    'chiasma',
    'chichi',
    'chicken',
    'chicomecoatl',
    'chiefs',
    'chieftain',
    'chien',
    'chigger',
    'chignon',
    'chihuahua',
    'childe',
    'childhood',
    'chilicote',
    'chimalapa',
    'chimbley',
    'chimpanzee',
    'chinamen',
    'chinchilla',
    'chine',
    'chinho',
    'chinook',
    'chinotti',
    'chipchap',
    'chipmunk',
    'chipped',
    'chiquito',
    'chiropractor',
    'chiseler',
    'chisolm',
    'chital',
    'chitter',
    'chivalric',
    'chivalrous',
    'chocolatey',
    'choctaw',
    'choices',
    'choler',
    'choluteca',
    'choosey',
    'chops',
    'chorai',
    'chordate',
    'chores',
    'chotts',
    'chough',
    'chouser',
    'chrisman',
    'chrismary',
    'christea',
    'christel',
    'christia',
    'christianson',
    'christl',
    'christoffel',
    'chromo',
    'chrysant',
    'chrysanthemum',
    'chrysops',
    'chrystal',
    'chukchi',
    'chump',
    'chumps',
    'chunkiest',
    'chunmei',
    'churchill',
    'churinga',
    'churn',
    'cicatrix',
    'cichlid',
    'cigua',
    'cilice',
    'cimex',
    'cinderel',
    'cineraria',
    'cingulate',
    'cinque',
    'cinter',
    'circadian',
    'circle',
    'circulate',
    'ciscos',
    'cithara',
    'citral',
    'citrons',
    'civies',
    'civility',
    'claimed',
    'claimer',
    'clairvoyants',
    'clam',
    'clamber',
    'clamorous',
    'clandestine',
    'clarance',
    'clarified',
    'clarin',
    'clarita',
    'clason',
    'classical',
    'clatty',
    'claudius',
    'claustrum',
    'claval',
    'claws',
    'cleancut',
    'cleanup',
    'clemens',
    'clepsydra',
    'clerks',
    'clethra',
    'clevie',
    'clients',
    'cliffs',
    'clifton',
    'climbed',
    'climber',
    'clinic',
    'clink',
    'clipper',
    'clitia',
    'clockhouse',
    'clocks',
    'clockwise',
    'cloherty',
    'clone',
    'clonus',
    'close',
    'clote',
    'cloudage',
    'clubs',
    'coagulate',
    'coaly',
    'coarse',
    'coast',
    'coater',
    'coati',
    'coatimundi',
    'cobble',
    'cobblers',
    'cobbra',
    'cobol',
    'cobra',
    'cobwebs',
    'cocain',
    'cocaine',
    'cochin',
    'cocker',
    'cockeyed',
    'cocking',
    'cockroach',
    'cocoa',
    'cocooned',
    'cod',
    'codebreaker',
    'codfish',
    'codicil',
    'coerced',
    'coeval',
    'coffeehouse',
    'coffin',
    'coffinmaker',
    'coghlan',
    'cogitate',
    'cohabitants',
    'cohesion',
    'coils',
    'cointer',
    'colder',
    'coldish',
    'colene',
    'coleridge',
    'coleslaw',
    'colias',
    'colicky',
    'collard',
    'colleague',
    'collegium',
    'collie',
    'collisions',
    'colloid',
    'cologs',
    'colon',
    'colorant',
    'colorate',
    'colorize',
    'colourblind',
    'colston',
    'colts',
    'columbic',
    'comart',
    'comate',
    'combaz',
    'combinator',
    'combo',
    'comfit',
    'comfort',
    'comfortable',
    'comix',
    'comma',
    'commanded',
    'commander',
    'commanding',
    'compatriot',
    'complement',
    'completer',
    'completing',
    'complex',
    'compliant',
    'complier',
    'compose',
    'compress',
    'compulsed',
    'computer',
    'computerise',
    'concentrate',
    'concentric',
    'concrete',
    'concussion',
    'condom',
    'conestoga',
    'confab',
    'confection',
    'confederacy',
    'confers',
    'confessions',
    'conform',
    'confucius',
    'confused',
    'conger',
    'congregate',
    'conjure',
    'connelly',
    'connexions',
    'conniption',
    'conquered',
    'conscience',
    'consciences',
    'consciousness',
    'conservative',
    'consolable',
    'console',
    'consolidated',
    'consonance',
    'constanta',
    'constitutions',
    'constructor',
    'consultant',
    'contemplative',
    'contemptible',
    'contemptuous',
    'content',
    'continuum',
    'contradiction',
    'contrary',
    'contribution',
    'controllers',
    'convair',
    'convected',
    'converse',
    'converses',
    'convict',
    'convolvulus',
    'coogan',
    'cookeys',
    'coolest',
    'cooling',
    'cooper',
    'copious',
    'copperfield',
    'copyist',
    'coquelicot',
    'coquet',
    'coquitlam',
    'corabelle',
    'coral',
    'coranto',
    'corban',
    'corbett',
    'cordilleran',
    'cordy',
    'coregonus',
    'corena',
    'corie',
    'corina',
    'corker',
    'corkey',
    'cormac',
    'cormorant',
    'cornea',
    'corners',
    'cornflake',
    'cornice',
    'cornishman',
    'cornual',
    'coronet',
    'corporates',
    'corporeal',
    'correal',
    'correct',
    'correy',
    'corrigan',
    'corruption',
    'corsair',
    'cortina',
    'corvettes',
    'corvo',
    'corydon',
    'cosimo',
    'cosine',
    'cosmetic',
    'cosmorama',
    'costard',
    'costarred',
    'costed',
    'costello',
    'costs',
    'costumes',
    'costuming',
    'cotte',
    'cottonmouth',
    'cottontail',
    'cotys',
    'couchy',
    'cougar',
    'couma',
    'coumara',
    'countersink',
    'countess',
    'countor',
    'counts',
    'couplet',
    'cousins',
    'coved',
    'cow',
    'coward',
    'cowhand',
    'cowkeeper',
    'coxswain',
    'coyan',
    'coyish',
    'coyle',
    'coyote',
    'cozen',
    'crab',
    'crabber',
    'crabby',
    'cradler',
    'craft',
    'cramped',
    'crane',
    'craney',
    'cranic',
    'crankless',
    'cranky',
    'crassula',
    'crataegus',
    'craving',
    'crawthumper',
    'craze',
    'creak',
    'creaks',
    'creatine',
    'creating',
    'creative',
    'creche',
    'credendum',
    'credenza',
    'creecy',
    'creen',
    'creeps',
    'cremone',
    'crepeau',
    'crescentia',
    'cricker',
    'crile',
    'criminologist',
    'crimp',
    'crinoid',
    'crinoline',
    'crista',
    'cristie',
    'cristina',
    'criterium',
    'criticaster',
    'criticism',
    'critter',
    'croci',
    'crocky',
    'crocodile',
    'cronet',
    'crony',
    'croppy',
    'croquette',
    'crosse',
    'crossways',
    'croteau',
    'crow',
    'crowds',
    'crozer',
    'crozier',
    'cruce',
    'cruche',
    'crucify',
    'crude',
    'cruise',
    'cruising',
    'crumble',
    'crumblier',
    'crumby',
    'crumpler',
    'crustacean',
    'crusty',
    'cruth',
    'cryptic',
    'cuarenta',
    'cuculla',
    'cudden',
    'cuerda',
    'cuirassier',
    'cuisse',
    'culebra',
    'culet',
    'culinary',
    'culled',
    'cumulate',
    'cunard',
    'cupholder',
    'cupper',
    'curate',
    'curcuma',
    'curcumas',
    'curlew',
    'curley',
    'curupira',
    'curver',
    'curvilinear',
    'cuscus',
    'cushing',
    'cusick',
    'customer',
    'customize',
    'cusumano',
    'cutesy',
    'cutlass',
    'cutlet',
    'cutline',
    'cutthroat',
    'cuttlefish',
    'cyanic',
    'cybernetic',
    'cyborgs',
    'cycles',
    'cyclic',
    'cycloid',
    'cynthy',
    'cypher',
    'cypress',
    'cyprus',
    'cyrenaic',
    'cyros',
    'cytherea',
    'd-day',
    'daaboul',
    'dabber',
    'dacca',
    'dachshund',
    'dacian',
    'dadaism',
    'dahoon',
    'daimen',
    'dairylea',
    'dairyman',
    'daisi',
    'dalcassian',
    'dalmatian',
    'damaged',
    'damaris',
    'damil',
    'damnation',
    'damocles',
    'damping',
    'danceable',
    'dangersome',
    'dangle',
    'danie',
    'danielak',
    'danize',
    'danny',
    'daphna',
    'dapped',
    'darkener',
    'darkens',
    'darker',
    'darkies',
    'darkness',
    'darnel',
    'darrack',
    'darrel',
    'darrin',
    'darshi',
    'dartboard',
    'dartman',
    'dashed',
    'dastardly',
    'databank',
    'dates',
    'datos',
    'datura',
    'daube',
    'dauphine',
    'davey',
    'davidh',
    'davidian',
    'dawne',
    'dawns',
    'daylights',
    'dayman',
    'daymare',
    'dayspring',
    'dayton',
    'dazing',
    'deadlocked',
    'deanery',
    'dearaujo',
    'deathy',
    'deaved',
    'debased',
    'debater',
    'debilitate',
    'debride',
    'debus',
    'decaf',
    'decafid',
    'decagon',
    'decatur',
    'decayed',
    'deceive',
    'decembrist',
    'decency',
    'decil',
    'decimate',
    'decision',
    'deckchair',
    'deckers',
    'deckie',
    'decking',
    'decolor',
    'decoupage',
    'decries',
    'decubitus',
    'dedicates',
    'deeann',
    'deena',
    'deer',
    'deere',
    'deermeat',
    'defeatism',
    'defect',
    'defensor',
    'defiant',
    'defined',
    'deflatable',
    'defloration',
    'deforestation',
    'deformative',
    'deformity',
    'defrance',
    'degenerative',
    'dehaan',
    'dehydration',
    'deidre',
    'deifier',
    'deipnophobia',
    'dejan',
    'dejected',
    'dekko',
    'dekle',
    'delage',
    'delaminate',
    'delano',
    'delat',
    'delawn',
    'delayer',
    'delight',
    'delila',
    'deliquescent',
    'delirious',
    'deliver',
    'delly',
    'delmor',
    'deloris',
    'delphinite',
    'delroy',
    'deluxe',
    'demarch',
    'demeo',
    'demijohn',
    'demimark',
    'demir',
    'demised',
    'demiss',
    'demons',
    'demur',
    'dendral',
    'denes',
    'denice',
    'dennie',
    'denny',
    'denominate',
    'dentin',
    'dentine',
    'depark',
    'depict',
    'depicting',
    'deposit',
    'depraved',
    'deprive',
    'deranger',
    'derates',
    'derelict',
    'dermis',
    'dervish',
    'descended',
    'desdemon',
    'desecration',
    'deserving',
    'designers',
    'desirae',
    'desires',
    'desiri',
    'desistance',
    'desolates',
    'despoiler',
    'despot',
    'dessa',
    'dessain',
    'destructive',
    'detailer',
    'determinant',
    'detin',
    'detlev',
    'detonations',
    'detour',
    'detours',
    'detur',
    'deuce',
    'deuteron',
    'deutzia',
    'devaluation',
    'developed',
    'devera',
    'devest',
    'deviated',
    'devious',
    'devoir',
    'devotes',
    'devow',
    'dewberry',
    'dewdrop',
    'dewit',
    'dewitte',
    'dextro',
    'dhangar',
    'dhava',
    'dhole',
    'dhoul',
    'diablo',
    'diagnose',
    'diaphane',
    'diccon',
    'dichter',
    'dickerson',
    'dickford',
    'didactic',
    'didani',
    'didie',
    'didine',
    'didus',
    'dielike',
    'diena',
    'diene',
    'dieri',
    'diets',
    'differences',
    'differentiator',
    'diffraction',
    'digestives',
    'dight',
    'dijian',
    'dikkop',
    'diktat',
    'dilated',
    'dilbert',
    'dimension',
    'dimitra',
    'dined',
    'dingar',
    'dingbats',
    'dingley',
    'dingo',
    'dinkey',
    'dinner',
    'dinners',
    'dinny',
    'dinosaur',
    'dipak',
    'dipietro',
    'diplopod',
    'diptera',
    'direction',
    'directory',
    'dirigent',
    'dirtbird',
    'disadventure',
    'disappear',
    'disappearance',
    'disazo',
    'disbelief',
    'discolor',
    'disconsolate',
    'discordia',
    'discording',
    'discount',
    'discoverer',
    'discovert',
    'discriminant',
    'discus',
    'disembodied',
    'disgrace',
    'disheart',
    'dislocator',
    'dismember',
    'disorderer',
    'disorient',
    'dispassioned',
    'dispatched',
    'dispirited',
    'display',
    'displayer',
    'dissave',
    'distad',
    'distances',
    'distinctive',
    'disturber',
    'ditch',
    'ditone',
    'ditto',
    'divergence',
    'dives',
    'divest',
    'divide',
    'divinely',
    'diviner',
    'diving',
    'divots',
    'divus',
    'diwata',
    'djins',
    'docherty',
    'docken',
    'documentary',
    'dodie',
    'dodo',
    'dog',
    'dogfish',
    'dogged',
    'dogie',
    'doglike',
    'dogtag',
    'doily',
    'doina',
    'dollop',
    'dolman',
    'dolmen',
    'dolomites',
    'dolphin',
    'domination',
    'dominiqu',
    'dominium',
    'donal',
    'donga',
    'donica',
    'donkey',
    'donned',
    'donnie',
    'donning',
    'donohue',
    'doodad',
    'doodlebug',
    'doolittle',
    'doree',
    'dorelia',
    'dories',
    'dormouse',
    'dorsal',
    'dorser',
    'dorter',
    'dosanjh',
    'dosers',
    'dosser',
    'dotan',
    'dotes',
    'dotson',
    'dotted',
    'dotterel',
    'double',
    'doubledecker',
    'doubts',
    'dougall',
    'douping',
    'doused',
    'dove',
    'dovelet',
    'dower',
    'downbeat',
    'downcome',
    'downless',
    'downs',
    'downtown',
    'downturn',
    'dowse',
    'draconis',
    'dragnet',
    'dragoman',
    'dragonfly',
    'drainage',
    'drainer',
    'drainpipe',
    'drakes',
    'drane',
    'draughtsman',
    'dreader',
    'dreads',
    'dreaminess',
    'dreamworld',
    'dredges',
    'dreep',
    'drench',
    'drenched',
    'drescher',
    'dresel',
    'dress',
    'dresser',
    'drever',
    'dreyfus',
    'dreyfuss',
    'dribbling',
    'drier',
    'drink',
    'drive',
    'drizzly',
    'dropped',
    'dropping',
    'dropsy',
    'droud',
    'drover',
    'drseuss',
    'drugless',
    'drumlin',
    'drumline',
    'drunks',
    'dryas',
    'dubose',
    'duck',
    'duckers',
    'duckies',
    'ducking',
    'duckwalk',
    'duello',
    'duenas',
    'dugong',
    'dulcea',
    'dullhead',
    'dulosis',
    'dumas',
    'dumbs',
    'dumper',
    'dunder',
    'dungs',
    'dunker',
    'dunlin',
    'dunsmore',
    'dupable',
    'dupes',
    'dupree',
    'durango',
    'duress',
    'durmast',
    'durovic',
    'durrell',
    'dusky',
    'dustbox',
    'dustman',
    'dustuck',
    'dusun',
    'dutiful',
    'dwale',
    'dweller',
    'dynamism',
    'dynamistic',
    'dyslogistic',
    'dyspepsia',
    'dziemian',
    'eagle',
    'eamonn',
    'eardrum',
    'earles',
    'earlier',
    'earlock',
    'earmark',
    'earring',
    'earrings',
    'earth',
    'earthenware',
    'earwig',
    'eastland',
    'ebenezer',
    'eccentrics',
    'echard',
    'echidna',
    'echinus',
    'eckler',
    'eclair',
    'econometrics',
    'ecstasy',
    'ecthyma',
    'edenize',
    'edlin',
    'edsel',
    'eduard',
    'educable',
    'edwin',
    'eeeeee',
    'eel',
    'efficacious',
    'efficience',
    'efficient',
    'egality',
    'eggfish',
    'egipto',
    'egret',
    'eidetic',
    'eikon',
    'eladio',
    'eland',
    'elanor',
    'elasmosaur',
    'elastica',
    'elberta',
    'elbow',
    'elding',
    'eldreth',
    'eleanore',
    'eleazar',
    'electrified',
    'electrocute',
    'electrodes',
    'electrolysis',
    'electrophone',
    'electrostatic',
    'electrotechnics',
    'elegances',
    'elephant',
    'elephantseal',
    'elephas',
    'elevator',
    'elevatory',
    'elfreda',
    'elgar',
    'elianora',
    'elided',
    'eliminable',
    'eliminator',
    'elinor',
    'elizabethan',
    'elk',
    'elkins',
    'eller',
    'ellie',
    'elsey',
    'elusions',
    'elusory',
    'elute',
    'elvera',
    'elvira',
    'elysia',
    'emacs',
    'emball',
    'embark',
    'embay',
    'embittered',
    'emblem',
    'embrica',
    'embryon',
    'emera',
    'emilee',
    'emilios',
    'eminence',
    'emirate',
    'emissary',
    'emmaline',
    'emmett',
    'emmey',
    'emogene',
    'emollient',
    'emond',
    'emory',
    'empathetic',
    'empathic',
    'emperors',
    'empress',
    'emu',
    'enamels',
    'enchanter',
    'encloud',
    'endang',
    'endeavours',
    'enderle',
    'endosteum',
    'endrys',
    'enforces',
    'engineman',
    'engle',
    'englishmen',
    'engrave',
    'engravers',
    'enhancer',
    'eniac',
    'enkidu',
    'ennead',
    'enrapt',
    'enrica',
    'enriquet',
    'enshroud',
    'ensign',
    'entach',
    'entails',
    'ental',
    'enteron',
    'entomb',
    'envelop',
    'enviable',
    'ephemeron',
    'ephialtes',
    'ephyra',
    'epical',
    'epicenter',
    'epicentral',
    'episcopalian',
    'epistropheus',
    'epomophorus',
    'equalling',
    'equilibrio',
    'equivocal',
    'erasement',
    'erastus',
    'erbach',
    'erection',
    'erena',
    'ergal',
    'ericsson',
    'eriksson',
    'erithacus',
    'erlenmeyer',
    'ermey',
    'erminia',
    'ernestine',
    'erode',
    'erroll',
    'erwin',
    'erykah',
    'erythrocyte',
    'escalus',
    'esclavage',
    'escobilla',
    'eskar',
    'eskimo',
    'esmond',
    'esparto',
    'esposito',
    'essed',
    'esson',
    'estelle',
    'ester',
    'estes',
    'estevam',
    'estherian',
    'estrange',
    'esurience',
    'etalon',
    'etheline',
    'ethelyn',
    'ether',
    'etherize',
    'ethically',
    'eulalia',
    'eulalie',
    'eunice',
    'euonymus',
    'euphonism',
    'euphori',
    'eurasian',
    'evangelian',
    'evaporative',
    'evened',
    'evens',
    'evensong',
    'everyman',
    'everyone',
    'evoked',
    'evokes',
    'evzone',
    'ewing',
    'exacta',
    'exaggerating',
    'excalibur',
    'excavating',
    'except',
    'exciton',
    'excitor',
    'exclude',
    'excoriation',
    'executant',
    'executed',
    'exegesis',
    'exegete',
    'exert',
    'exfoliate',
    'exhibits',
    'existential',
    'exophoria',
    'exorcise',
    'exordia',
    'exotic',
    'expatriate',
    'expiry',
    'explains',
    'exploiters',
    'explorations',
    'explorers',
    'explosion',
    'expone',
    'exponent',
    'exposition',
    'expresso',
    'extemporaneity',
    'externity',
    'extraneous',
    'extravert',
    'extremal',
    'eyeball',
    'eyeballs',
    'eyebrow',
    'eyeglasses',
    'eyelashes',
    'eyeline',
    'eyeshot',
    'eyewink',
    'ezekiel',
    'fabio',
    'fabler',
    'fabrizio',
    'faceman',
    'facer',
    'factice',
    'facto',
    'fagan',
    'fagottino',
    'fahey',
    'failsafe',
    'fairish',
    'fairless',
    'fairy',
    'falchion',
    'falcon',
    'faliscan',
    'fallacy',
    'faller',
    'fanes',
    'fanner',
    'fantasize',
    'fatback',
    'fatidical',
    'feels',
    'ferret',
    'ferrous',
    'ferule',
    'fewer',
    'fiction',
    'fiducial',
    'filmer',
    'finch',
    'findings',
    'firearms',
    'fish',
    'flabs',
    'flamer',
    'flamingo',
    'flamingos',
    'flatland',
    'flattop',
    'fletcher',
    'flightless',
    'flits',
    'flounder',
    'fluffs',
    'fly',
    'flycatcher',
    'fogger',
    'foothill',
    'forehead',
    'forger',
    'forgotten',
    'fortepiano',
    'fortes',
    'fortuneteller',
    'forzando',
    'fossa',
    'fox',
    'frazzled',
    'freemen',
    'frigatebird',
    'friseur',
    'frog',
    'fugio',
    'funkia',
    'gaffe',
    'galago',
    'gallican',
    'gar',
    'gargantuan',
    'gasped',
    'gaur',
    'gazelle',
    'gecko',
    'geology',
    'geometry',
    'gerbil',
    'gharial',
    'giantpanda',
    'gibbon',
    'gibed',
    'giggled',
    'gingiva',
    'giraffe',
    'girlies',
    'gizzard',
    'glasses',
    'glioma',
    'globefish',
    'gloms',
    'glucose',
    'glycerol',
    'gnat',
    'gnu',
    'goat',
    'going',
    'goldfinch',
    'goldfish',
    'goodwill',
    'goose',
    'gooses',
    'gopher',
    'gorilla',
    'goshawk',
    'gouger',
    'graciousness',
    'granulator',
    'grasper',
    'grasshopper',
    'graybeard',
    'greener',
    'greengage',
    'gregariousness',
    'greyhound',
    'greylag',
    'grievance',
    'griffin',
    'gript',
    'groggy',
    'grouse',
    'guanaco',
    'guars',
    'guernsey',
    'guineafowl',
    'guineapig',
    'gull',
    'gulley',
    'gummers',
    'gunslinger',
    'guppy',
    'habanera',
    'hadron',
    'hadrons',
    'halbert',
    'haler',
    'hamster',
    'handbasket',
    'hangfire',
    'hardline',
    'hare',
    'harmonious',
    'harpy',
    'harrier',
    'hautbois',
    'havanese',
    'havens',
    'havocs',
    'hawk',
    'headwaiter',
    'heartbreak',
    'hedgehog',
    'heeler',
    'hellion',
    'hematite',
    'hemoglobin',
    'henna',
    'herbivore',
    'heron',
    'herring',
    'heterosexual',
    'highbrows',
    'hillock',
    'hilum',
    'himalayan',
    'hippopotamus',
    'hoc',
    'hocus',
    'hoers',
    'hoising',
    'hollyhocks',
    'holts',
    'hometown',
    'hoops',
    'hopeful',
    'hornet',
    'horse',
    'hubcaps',
    'hubristic',
    'huddled',
    'human',
    'humiliation',
    'hummingbird',
    'hydroponics',
    'hyena',
    'ibis',
    'idiots',
    'idolatrous',
    'iguana',
    'illegal',
    'imagining',
    'imbued',
    'immerging',
    'immolator',
    'immune',
    'impala',
    'impious',
    'improve',
    'impulsively',
    'inbounds',
    'incarnate',
    'incognitos',
    'indecency',
    'index',
    'indexical',
    'indri',
    'indris',
    'indulger',
    'industry',
    'inequality',
    'inexplicit',
    'infest',
    'ingots',
    'insect',
    'inspector',
    'inspired',
    'installation',
    'insular',
    'integrate',
    'intercom',
    'intercoms',
    'interflow',
    'internal',
    'interregnum',
    'invigoration',
    'inviscid',
    'invite',
    'irater',
    'iridescent',
    'ironwork',
    'irradiation',
    'irregular',
    'irrelevantly',
    'jacanas',
    'jackal',
    'jaguar',
    'jalop',
    'janitors',
    'javanese',
    'jay',
    'jazzing',
    'jellyfish',
    'jenny',
    'jeopardise',
    'jerries',
    'jocund',
    'jollier',
    'jostler',
    'jujube',
    'juking',
    'kabiki',
    'kakapo',
    'kangaroo',
    'kerning',
    'keyless',
    'kibbutz',
    'killing',
    'kilohertz',
    'kilts',
    'kindle',
    'kingdoms',
    'kingfisher',
    'kinkajou',
    'kiwi',
    'kiwifruit',
    'koala',
    'kolhoz',
    'kooks',
    'kouprey',
    'kudu',
    'kwashiorkor',
    'labradoodle',
    'labyrinth',
    'laceration',
    'lacrosse',
    'ladybird',
    'lambs',
    'lamebrain',
    'landlords',
    'landmark',
    'lapwing',
    'lark',
    'latria',
    'launce',
    'laureate',
    'lawless',
    'lazying',
    'leafy',
    'lease',
    'lectures',
    'lefty',
    'lemming',
    'lemon',
    'lemur',
    'leopard',
    'lesbians',
    'levering',
    'levied',
    'libra',
    'lieve',
    'lifer',
    'liger',
    'lingering',
    'lining',
    'lion',
    'lionfish',
    'lipomas',
    'litotes',
    'lizard',
    'llama',
    'lobations',
    'lobster',
    'locoed',
    'locust',
    'lollygag',
    'loment',
    'longhair',
    'longlines',
    'longshoremen',
    'loris',
    'loudness',
    'louie',
    'loupes',
    'louse',
    'lovebirds',
    'lovers',
    'lucidity',
    'ludicrous',
    'lumen',
    'lymph',
    'lynx',
    'lyrebird',
    'macaw',
    'macrophage',
    'madonna',
    'madras',
    'magenta',
    'magistral',
    'magpie',
    'maidenhead',
    'maile',
    'maimed',
    'malices',
    'mallard',
    'malpractice',
    'maltese',
    'malvasia',
    'manatee',
    'manche',
    'mandrill',
    'manning',
    'mariachi',
    'marijuanas',
    'markhor',
    'martello',
    'marten',
    'massa',
    'masseurs',
    'masterly',
    'masterstroke',
    'mastiff',
    'mastoid',
    'mavie',
    'mayfly',
    'meanwhile',
    'meatmen',
    'mechanic',
    'medical',
    'mediums',
    'meerkat',
    'megalomaniac',
    'merchants',
    'merrily',
    'metalsmith',
    'metatarsi',
    'meteorology',
    'microtome',
    'miffs',
    'migraine',
    'millage',
    'milled',
    'millipede',
    'mindsets',
    'minima',
    'mink',
    'mirth',
    'mistermed',
    'mitten',
    'mixers',
    'mocha',
    'moggie',
    'mogul',
    'moguls',
    'moirai',
    'molar',
    'mole',
    'molly',
    'monastery',
    'mongeese',
    'mongoose',
    'mongrel',
    'monikers',
    'monkey',
    'monkeyshines',
    'monomania',
    'moorhen',
    'moors',
    'moose',
    'moped',
    'moralistic',
    'moratoria',
    'mosks',
    'mosquito',
    'mosso',
    'moth',
    'mothball',
    'motility',
    'motivator',
    'motorman',
    'mouse',
    'mousse',
    'mule',
    'mullite',
    'multijet',
    'musician',
    'mutine',
    'myalgic',
    'named',
    'namelessly',
    'nappy',
    'narwhal',
    'naturalistic',
    'naturalists',
    'navies',
    'neanderthal',
    'nepenthe',
    'netlike',
    'neuter',
    'newborns',
    'newfoundland',
    'newt',
    'nibble',
    'nightingale',
    'ninjas',
    'nobodies',
    'nodder',
    'nonbelief',
    'normalcy',
    'normality',
    'norms',
    'novelette',
    'numbat',
    'nympholept',
    'obscenity',
    'obsoletes',
    'ocelot',
    'octopus',
    'oddballs',
    'offside',
    'offsprings',
    'okapi',
    'olm',
    'omnivora',
    'oncogene',
    'onions',
    'onomatopoeia',
    'opossum',
    'oppose',
    'orache',
    'organismal',
    'orthodox',
    'oryx',
    'ostraca',
    'ostrich',
    'otter',
    'outlandish',
    'outlet',
    'outside',
    'overdogs',
    'overshadow',
    'overview',
    'owl',
    'ox',
    'oxeyes',
    'oxides',
    'oyster',
    'ozonic',
    'pacas',
    'padauk',
    'pademelon',
    'pager',
    'painful',
    'palindrome',
    'palmar',
    'palmetto',
    'pancreatitis',
    'panicked',
    'panther',
    'panthers',
    'pantomime',
    'papain',
    'papal',
    'paperweight',
    'papillon',
    'paradise',
    'parlay',
    'parrot',
    'parsed',
    'parser',
    'parterres',
    'partridge',
    'paseos',
    'passe',
    'passwords',
    'pastorale',
    'patness',
    'patter',
    'pauses',
    'peacemaker',
    'peacock',
    'peafowl',
    'pecky',
    'pediatric',
    'pedicab',
    'pedlers',
    'pedophile',
    'peery',
    'pekingese',
    'pelican',
    'penguin',
    'penning',
    'pennyroyal',
    'pensione',
    'penstemon',
    'peponidas',
    'perfecto',
    'peroxid',
    'persian',
    'perturbation',
    'petal',
    'pewit',
    'pheasant',
    'phosphate',
    'photon',
    'picoline',
    'pig',
    'pigeon',
    'pika',
    'pike',
    'pinnacle',
    'pinole',
    'pinwheel',
    'pioneering',
    'piperazine',
    'pipsqueak',
    'piques',
    'piranha',
    'pirogue',
    'pisiform',
    'placebos',
    'plasmoid',
    'platypus',
    'playland',
    'please',
    'pleonastic',
    'plimsol',
    'plotter',
    'poesy',
    'poetess',
    'pointer',
    'politics',
    'polled',
    'pommies',
    'pondering',
    'pony',
    'poodle',
    'pooled',
    'porcupine',
    'porkpie',
    'porpoise',
    'positive',
    'possum',
    'postcard',
    'postfire',
    'poundage',
    'pourer',
    'poverty',
    'prawn',
    'preatomic',
    'precognition',
    'preview',
    'primeval',
    'princesse',
    'prisons',
    'processor',
    'proclaimed',
    'progression',
    'prophecy',
    'prosecutor',
    'prostitute',
    'protesting',
    'protomartyr',
    'prune',
    'pseudonym',
    'puffin',
    'puffs',
    'pug',
    'pullover',
    'pulvinus',
    'puma',
    'purdah',
    'pyrogenicity',
    'pyrrhic',
    'quail',
    'qualm',
    'quarts',
    'quebrachos',
    'quelea',
    'quetzal',
    'quietens',
    'quokka',
    'quoll',
    'rabbit',
    'rabboni',
    'raccoon',
    'racker',
    'racon',
    'ragdoll',
    'rail',
    'raincoat',
    'ram',
    'raphia',
    'rat',
    'ratiocinator',
    'rattlesnake',
    'raven',
    'razers',
    'realest',
    'reaper',
    'reasonable',
    'receipt',
    'recipe',
    'reddeer',
    'redips',
    'redout',
    'redpanda',
    'reefer',
    'reflection',
    'refuted',
    'regularity',
    'reindeer',
    'reinvent',
    'relaxing',
    'relentless',
    'religion',
    'removed',
    'repair',
    'replenished',
    'represented',
    'requestor',
    'restrict',
    'retort',
    'retractor',
    'reversible',
    'revulsion',
    'rhinoceros',
    'rhizobium',
    'riced',
    'ridicule',
    'rille',
    'robin',
    'rolfers',
    'rook',
    'rooky',
    'roseola',
    'rotavirus',
    'rotted',
    'rottweiler',
    'rousseau',
    'routeman',
    'rovers',
    'roving',
    'rubeola',
    'ruff',
    'rumpus',
    'runaround',
    'russet',
    'ruthlessness',
    'rykes',
    'sabed',
    'saddlers',
    'salads',
    'salamander',
    'sales',
    'salmon',
    'saltire',
    'saltish',
    'samaras',
    'samba',
    'sanatorium',
    'sanded',
    'sandpiper',
    'santalol',
    'saola',
    'sapid',
    'sapient',
    'sardine',
    'sarges',
    'sassiest',
    'satsumas',
    'sawbucks',
    'sawer',
    'sawing',
    'saxes',
    'scabs',
    'scaled',
    'scallywags',
    'scalp',
    'scalper',
    'scampers',
    'scams',
    'scandic',
    'scarabaeus',
    'scarabs',
    'scarcity',
    'scarlet',
    'scarped',
    'scatt',
    'scattershot',
    'scheduler',
    'schematic',
    'scheme',
    'schipperke',
    'schizophrenic',
    'schlock',
    'schmelze',
    'schnaps',
    'schnecken',
    'schrik',
    'schuit',
    'schuss',
    'science',
    'sciences',
    'scimitar',
    'scintillator',
    'scions',
    'scirocco',
    'scissor',
    'sclera',
    'scoop',
    'scoot',
    'scope',
    'scorch',
    'scorching',
    'scorer',
    'scorner',
    'scorpion',
    'scouth',
    'scrag',
    'scraps',
    'scrimpy',
    'scriptures',
    'scrod',
    'scroll',
    'scrounge',
    'scruff',
    'sculpt',
    'scumbag',
    'scumble',
    'scurry',
    'scuzzy',
    'scythe',
    'scythed',
    'seahorse',
    'seal',
    'seaside',
    'seatbelts',
    'seated',
    'seaters',
    'seawan',
    'seaward',
    'seaweeds',
    'sebasic',
    'seconds',
    'secret',
    'secretive',
    'secretor',
    'section',
    'sectored',
    'sedated',
    'sedater',
    'sedatives',
    'sedimentary',
    'seduced',
    'seemly',
    'seersucker',
    'segment',
    'segued',
    'segueing',
    'seiner',
    'seining',
    'seise',
    'seiser',
    'seism',
    'selachian',
    'seldom',
    'sellouts',
    'selvas',
    'semblance',
    'senary',
    'senna',
    'sensorium',
    'separated',
    'septs',
    'serines',
    'serval',
    'setae',
    'sexualized',
    'shakable',
    'shaly',
    'shaman',
    'shamus',
    'shandies',
    'shaping',
    'shark',
    'shawm',
    'sheep',
    'sheeting',
    'shelver',
    'sheriff',
    'shott',
    'shove',
    'shrew',
    'shrimp',
    'siamese',
    'siberian',
    'sided',
    'sidetracked',
    'sighless',
    'signal',
    'signor',
    'silanes',
    'silhouette',
    'silicon',
    'silly',
    'simars',
    'simmer',
    'simoniac',
    'simoom',
    'simpleminded',
    'singly',
    'sirens',
    'sizzles',
    'skellum',
    'sketch',
    'skims',
    'skinkers',
    'skunk',
    'slammer',
    'slaters',
    'sledged',
    'slinking',
    'sloth',
    'smackers',
    'smarmy',
    'smokers',
    'smoldering',
    'snail',
    'snails',
    'snake',
    'snakebite',
    'snakey',
    'snarling',
    'snips',
    'snobby',
    'snorkeling',
    'snowdrop',
    'snowdrops',
    'snowshoe',
    'soave',
    'socked',
    'sokols',
    'solarise',
    'soling',
    'solitude',
    'solver',
    'somali',
    'sophies',
    'soundless',
    'sourish',
    'spacial',
    'spancel',
    'sparrow',
    'spawners',
    'species',
    'spectators',
    'speculate',
    'speer',
    'spelter',
    'spent',
    'spice',
    'spider',
    'spieler',
    'spiritually',
    'splay',
    'splendent',
    'splendiferous',
    'sponge',
    'sportsmen',
    'sprit',
    'squeal',
    'squid',
    'squirrel',
    'squirting',
    'stacker',
    'stallions',
    'stampeded',
    'staple',
    'starfish',
    'starling',
    'starship',
    'starvation',
    'stele',
    'stelic',
    'stengah',
    'steric',
    'stingray',
    'stinkbug',
    'stirrup',
    'stoat',
    'stoop',
    'stoper',
    'stork',
    'streamliner',
    'street',
    'strenuous',
    'stripling',
    'stubbles',
    'stupid',
    'stylar',
    'subatom',
    'subfusc',
    'subspace',
    'sucks',
    'suddens',
    'suedes',
    'suing',
    'sundering',
    'sunshiny',
    'supershow',
    'superstardom',
    'supervene',
    'surcease',
    'surrey',
    'suspected',
    'suzerain',
    'swallow',
    'swan',
    'sweatband',
    'switchers',
    'syllogist',
    'sylvan',
    'syphered',
    'systemic',
    'tabloids',
    'tafia',
    'tailcoat',
    'takeout',
    'tang',
    'tapadera',
    'tapir',
    'tarantas',
    'tariff',
    'tarsier',
    'tastier',
    'tasty',
    'taunting',
    'tawer',
    'taxidermist',
    'teenage',
    'telegrams',
    'telephoto',
    'tenant',
    'tenons',
    'termite',
    'terrorized',
    'tessera',
    'testimony',
    'tetra',
    'tewing',
    'thanking',
    'theist',
    'thieving',
    'thorax',
    'thousand',
    'thrilling',
    'throne',
    'thrower',
    'thrush',
    'thunderstorm',
    'thyroxine',
    'tiffany',
    'tiger',
    'tilak',
    'tilled',
    'tinfoil',
    'tingler',
    'tinkle',
    'tipple',
    'toad',
    'tobacconist',
    'toking',
    'tommed',
    'toner',
    'tonic',
    'tonights',
    'tonsured',
    'tootle',
    'topkick',
    'torot',
    'torpedos',
    'torpor',
    'tortoise',
    'toucan',
    'touchable',
    'toughie',
    'tovarish',
    'toxicologist',
    'trachea',
    'tracing',
    'tracking',
    'tradition',
    'transact',
    'transform',
    'transistors',
    'tressed',
    'trigs',
    'trinity',
    'trioxide',
    'tritoma',
    'tropicbird',
    'trout',
    'trucker',
    'trust',
    'tuatara',
    'tuner',
    'tupelo',
    'turkey',
    'turmeric',
    'turtle',
    'tutorial',
    'tzarina',
    'uakari',
    'uguisu',
    'ultrasonic',
    'umbrellabird',
    'umiaq',
    'unaccountably',
    'unacted',
    'undercount',
    'underlain',
    'underling',
    'undermined',
    'unladylike',
    'unmercifully',
    'unrecorded',
    'unreliable',
    'unremarkable',
    'unshackled',
    'unspecific',
    'uppercut',
    'utilize',
    'utilizer',
    'validity',
    'valours',
    'vanished',
    'vaultier',
    'vegan',
    'veining',
    'vermillions',
    'vertebras',
    'vibrio',
    'viceless',
    'videotape',
    'viking',
    'vilification',
    'vineal',
    'viper',
    'vises',
    'vituperative',
    'vivers',
    'vocalist',
    'vodkas',
    'vomer',
    'voyageurs',
    'vulture',
    'waddie',
    'wafer',
    'waggle',
    'waiting',
    'wakened',
    'walies',
    'wallaby',
    'wallet',
    'walrus',
    'wampum',
    'wangler',
    'wanton',
    'wared',
    'warship',
    'warthog',
    'warthogs',
    'washy',
    'wasp',
    'watercolors',
    'waylay',
    'weasel',
    'weedlike',
    'westwards',
    'whale',
    'whammo',
    'whippet',
    'whitier',
    'whoever',
    'wildebeest',
    'wimple',
    'wingy',
    'winterberry',
    'wipers',
    'wivern',
    'woesome',
    'wolf',
    'wolverine',
    'wombat',
    'wonderful',
    'wonders',
    'woodcock',
    'woodlouse',
    'woodpecker',
    'woofs',
    'workbench',
    'worker',
    'worm',
    'wound',
    'woundless',
    'wrasse',
    'wrath',
    'wren',
    'wries',
    'yaird',
    'yak',
    'yealing',
    'yeanling',
    'yucca',
    'zaffre',
    'zapateo',
    'zappiest',
    'zebra',
    'zebu',
    'zelkova',
    'zillionaire',
    'zonkey',
    'zooks',
    'zorse',
]

SOCIAL_NETWORKS = {
    'facebook': 'facebook.com/{}',
    'twitter': 'twitter.com/{}',
    'instagram': 'instagram.com/{}',
    'vk': 'vk.com/{}',
}



"""Specific data provider for Ukraine (uk)."""

from typing import Optional

from mimesis.builtins.base import BaseSpecProvider
from mimesis.enums import Gender
from mimesis.utils import pull

__all__ = ['UkraineSpecProvider']


class UkraineSpecProvider(BaseSpecProvider):
    """Class that provides special data for Ukraine (uk)."""

    def __init__(self, *args, **kwargs):
        """Initialize attributes."""
        super().__init__(*args, **kwargs)
        self._data = pull('builtin.json', 'uk')

    class Meta:
        """The name of the provider."""

        name = 'ukraine_provider'

    def patronymic(self, gender: Optional[Gender] = None) -> str:
        """Generate random patronymic name.

        :param gender: Gender of person.
        :type gender: str or int
        :return: Patronymic name.
        """
        gender = self._validate_enum(gender, Gender)
        patronymics = self._data['patronymic'][gender]
        return self.random.choice(patronymics)
